@@ -68,6 +68,9 @@ class TransportABC(abc.ABC):
     def span_context(self) -> Type[BaseTraceContext]:
         pass
 
+    def endpoint(self, local_endpoint):
+        pass
+
 
 class StubTransport(TransportABC):
     """Dummy transport, which logs spans to a limited queue."""
@@ -276,9 +279,11 @@ class ThriftTransport(TransportABC):
         self._batch_manager.add(record)
 
     async def _send_data(self, data: List[Record]) -> bool:
+        if not data:
+            return True
         batch = self.jaeger_thrift.Batch()
         process = self.jaeger_thrift.Process()
-        process.serviceName = "test"
+        process.serviceName = data[0].entrypoint_servicename
 
         batch.process = process
         spans = []
@@ -287,7 +292,7 @@ class ThriftTransport(TransportABC):
             span.traceIdLow = int(record.context.trace_id)
             span.traceIdHigh = 0
             span.spanId = int(record.context.span_id)
-            span.parentSpanId = (
+            span.parentSpanId = int(
                 record.context.parent_id if record.context.parent_id else 0
             )
             span.operationName = record._name
